@@ -15,12 +15,21 @@ class MACAddressField(models.Field):
     __metaclass__ = models.SubfieldBase
     dialect = None
     
-    def __init__(self, integer=True, *args, **kwargs): # Custom __init__ to accept new "integer" boolean argument to support specification of string or integer storage. Defaults to True (for now).
-        self.integer = integer
+    def __init__(self, *args, **kwargs):
+        self.integer = kwargs.pop('integer', True)
         if not self.integer: # If storing MAC address as string, set max_length to default (17) or use supplied kwarg value.
             kwargs['max_length'] = kwargs.get('max_length', 17)
         super(MACAddressField, self).__init__(*args, **kwargs)
-    
+
+
+    def deconstruct(self):
+        ''' Django 1.7 migrations require this method
+            https://docs.djangoproject.com/en/dev/howto/custom-model-fields/#field-deconstruction
+        '''
+        name, path, args, kwargs = super(MACAddressField, self).deconstruct()
+        kwargs['integer'] = self.integer
+        return name, path, args, kwargs
+
     @classmethod
     def set_dialect(cls, new_dialect_clazz):
         ''' Setting dialect for EUI (MAC addresses) globally to this Field
@@ -77,7 +86,7 @@ class MACAddressField(models.Field):
         if lookup_type in ('exact', 'iexact', 'icontains', 'icontains'):
             try:
                 return self.get_prep_value(value)
-            except AddrFormatError, e:
+            except AddrFormatError:
                 return None
         else:
             raise TypeError('Lookup type %r not supported.' % lookup_type)
